"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringify = exports.parse = exports.isMeasureType = void 0;
const replay_1 = require("@puppeteer/replay");
function isMeasureType(str) {
    switch (str) {
        case 'navigate':
        case 'snapshot':
        case 'startTimespan':
        case 'endTimespan':
            return true;
        default:
            return false;
    }
}
exports.isMeasureType = isMeasureType;
function parse(recordingJson) {
    // custom events to exclude from the default parser
    const ufArr = [];
    // filter out user-flow specific actions
    const steps = recordingJson.steps.filter((value, index) => {
        if (isMeasureType(value === null || value === void 0 ? void 0 : value.type)) {
            ufArr[index] = value;
            return false;
        }
        return true;
    });
    // parse the clean steps
    const parsed = (0, replay_1.parse)(Object.assign(Object.assign({}, recordingJson), { steps }));
    // add in user-flow specific actions
    ufArr.forEach((value, index) => {
        value && (parsed.steps.splice(index, 0, value));
    });
    // parse customEvents from our stringify function
    parsed.steps = parsed.steps.map((step) => {
        if (step.type === replay_1.StepType.CustomStep && isMeasureType(step.name)) {
            const { name: type, parameters } = step;
            return { type, parameters };
        }
        return step;
    });
    return parsed;
}
exports.parse = parse;
function stringify(enrichedRecordingJson) {
    const { title, steps } = enrichedRecordingJson;
    const standardizedJson = {
        title,
        steps: (steps).map((step) => {
            if (isMeasureType(step.type)) {
                return userFlowStepToCustomStep(step);
            }
            return step;
        })
    };
    return JSON.stringify(standardizedJson);
}
exports.stringify = stringify;
function userFlowStepToCustomStep(step) {
    const { type: name, parameters } = step;
    const stdStp = {
        type: replay_1.StepType.CustomStep,
        name,
        parameters
    };
    return stdStp;
}
//# sourceMappingURL=utils.js.map